@@ -158,7 +158,7 @@ def GetUserBadgesList(user_url):
         user_url (str): 链接字符串，需要加上 https
 
     Returns:
-        list: 用户被喜欢数（被点赞数）
+        list: 用户徽章列表
     """
     html = requests.get(user_url,headers = UA)
     source = bs4.BeautifulSoup(html.content,parser)
@@ -503,4 +503,70 @@ def GetAssetsRankList(start = 1):
         temp = "".join(temp)
         info["assets"] = float(temp)
         result_list.append(info)
-    return result_list
\ No newline at end of file
+    return result_list
+
+def GetArticleHtml(article_url):
+    """该函数接收文章链接，并以 HTML 格式返回文章内容
+
+    目前对图片块的处理还存在一些问题，会有多余的参数。
+
+    Args:
+        article_url (str): 文章链接
+
+    Returns:
+        str: HTML 格式的文章内容
+    """
+    # TODO:解决图片块的多余参数问题
+    html = requests.get(article_url,headers = UA)
+    source = bs4.BeautifulSoup(html.content,parser)
+    raw_data = str(source.find("article"))
+    result = Process_HTML(raw_data)
+    return result
+
+def GetArticleText(article_url):
+    """该函数接收文章链接，并以纯文本格式返回文章内容
+
+    文章中的图片块会被丢弃，但图片描述会保留
+
+    Args:
+        article_url (str): 文章链接
+
+    Returns:
+        str: 纯文本格式的文章内容
+    """
+    html = requests.get(article_url,headers = UA)
+    source = bs4.BeautifulSoup(html.content,parser)
+    result = str(source.find("article").text)
+    result = result.replace("\n","")
+    return result
+
+def GetUserArticlesList(user_url,page = 1):
+    url = user_url + "?page=" + str(page)
+    html = requests.get(url,headers = request_UA)
+    source  = bs4.BeautifulSoup(html.content,parser)
+    html_list = source.findAll("a",class_ = "title",href = True)
+    result_list = []
+    for item in html_list:
+        result_list.append("https://www.jianshu.com" + item["href"])
+    return result_list
+
+def GetDailyArticleRankList():
+    """该函数返回日更排行榜中用户的基础信息
+
+    Returns:
+        list: 包含日更用户基础信息的列表
+    """
+    source = requests.get("https://www.jianshu.com/asimov/daily_activity_participants/rank",headers = request_UA)
+    source = json.loads(source.content)
+    raw_data = source["daps"]
+    result_list = []
+    for item in raw_data:
+        info = {}
+        info["ranking"] = item["rank"]
+        info["days"] = item["checkin_count"]
+        info["name"] = item["nickname"]
+        info["slug"] = item["slug"]
+        result_list.append(info)
+    return result_list
+
+print(GetArticleText("https://www.jianshu.com/p/d1bef91888d8"))
\ No newline at end of file
